package dokeysto

  1. Overview
  2. Docs

Module Dokeysto.DbSource

Sourcetype filename = string
Read-only persistent string key to string value hash table
Sourcemodule RO : sig ... end
Read-only persistent string key to string value hash table (values are compressed on disk)
Sourcemodule ROZ : sig ... end
Read-write persistent string key to string value hash table
Sourcemodule RW : sig ... end
Read-write persistent string key to string value hash table (values are compressed on disk)
Sourcemodule RWZ : sig ... end